yuima.cogarch-class: Class for the mathematical description of CoGarch(p,q) model
Description
The yuima.cogarch class is a class of the yuima package that extends the yuima.model-class.
Objects from the Class
Objects can be created by calls of the function setCogarch. Extends
Class "yuima.model", directly.