yuima.cogarch-class: Class for the mathematical description of CoGarch(p,q) model
Description
The yuima.cogarch class is a class of the yuima package that extends the yuima.model-class.Objects from the Class
Objects can be created by calls of the function setCogarch.item
hurst:jump.coeff:measure:measure.type:parameter:state.variable:jump.variable:time.variable:noise.number:equation.number:dimension:solve.variable:xinit:J.flag:
code
"expression"Extends
Class "yuima.model", directly.